@@ -39,9 +39,9 @@ class BaseProvider(ABC):
         """Get multiple parameter placeholders for this database dialect."""
         pass
 
-    @abstractmethod
-    async def create_tables(self):
-        pass
+    def get_table_identifier(self, app_label: str, table_base_name: str) -> str:
+        """Get the table identifier for queries. Override in provider if needed."""
+        return f'"{app_label}_{table_base_name}"'
 
     @abstractmethod
     def serialize(self, value: Any) -> str:
@@ -51,3 +51,10 @@ class BaseProvider(ABC):
     def deserialize(self, value: str) -> Any:
         pass
 
+    # Optional hook: providers can implement automatic full-text setup during migrations
+    async def setup_full_text(self, app_label: str, table_base_name: str, search_meta: dict, fields: Dict[str, Any]):
+        """Create database-specific full-text search structures.
+
+        Default implementation does nothing. Providers may override.
+        """
+        return
